import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, scaleBand, scaleLinear, max, range } from 'd3';

const csvUrl = 'data.csv';

const width = 960;
const height = 500;
const margin = { top: 20, right: 20, bottom: 20, left: 20 };

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      d.population = +d.population;
      return d;
    };
    const num = range(10)
    csv(csvUrl, row).then((data) => {
      console.log(data)
      setData(data);
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map((d) => d.country))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.population)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left}, ${margin.top})`}>
        {data.map((d) => (
          <rect
            x={0}
            y={yScale(d.country)}
            width={xScale(d.population)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
